#include <stdio.h>
#include <stdlib.h>
#include <errno.h>
#include <Ws2tcpip.h>
#include <sys/types.h>

int main(int argc, char *argv[])
{
    if (argc != 2)
    {
        fprintf(stderr, "Usage: %s hostname\n", argv[0]);
        return 1;
    }

    // Enable WinSock2
    WORD wVersionRequested;
    wVersionRequested = MAKEWORD( 2, 2 );

    WSADATA wsaData;
    int rc;
    rc = WSAStartup( wVersionRequested, &wsaData );
    if (rc != 0)
    {
        fprintf(stderr, "Cannot find an usable WinSock2 dll");
        exit(1);
    }

    struct addrinfo hints;
    memset(&hints, 0, sizeof hints);
    hints.ai_family = AF_UNSPEC; // AF_INET or AF_INET6 to force version
    hints.ai_socktype = SOCK_STREAM;
 
    struct addrinfo *results;
    if ((rc = getaddrinfo(argv[1], NULL, &hints, &results)) != 0)
    {
        fprintf(stderr, "getaddrinfo: %s\n", gai_strerror(rc));
        WSACleanup();
        return 2;
    }
 
    struct addrinfo *result;
    for(result = results; result != NULL; result = result->ai_next)
    {
        void *addr;
 
        switch (result->ai_family)
        {
            case AF_INET:
            {
                sockaddr_in *sockaddr_in = (struct sockaddr_in *)result->ai_addr;
                printf("Hostname: %s\n", argv[1]);
                printf("IP Address: %s\n", inet_ntoa(sockaddr_in->sin_addr));
                break;
            }
            case AF_INET6:
            {
                struct sockaddr_in6 *ipv6 = (struct sockaddr_in6 *)result->ai_addr;
                addr = &(ipv6->sin6_addr);
 
                /* convert the IP to a string and print it: */
                char ipstr[INET6_ADDRSTRLEN];
                inet_ntop(result->ai_family, addr, ipstr, sizeof ipstr);
 
                printf("Hostname: %s\n", argv[1]);
                printf("IP Address: %s\n", ipstr);
                break;
            }
        }

        // Just print the first address
        break;
    }

    freeaddrinfo(results); // free the linked list
 
    WSACleanup();
    return 0;
}
